@@ -9,7 +9,7 @@ if platform.system( ).lower( ) == "windows":
     default_driver = "C"
 elif platform.system( ).lower( ) == "darwin":
     default_path = Path( os.environ[ 'HOME' ], "Desktop" )
-    default_driver = ""
+    default_driver = "Macintosh HD"
 else:
     pass
 
